@@ -11,7 +11,7 @@ use WWW::LogicBoxes::Types qw( NexusPurpose NexusCategory );
 
 extends 'WWW::LogicBoxes::Contact';
 
-our $VERSION = '1.5.0'; # VERSION
+our $VERSION = '1.6.0'; # VERSION
 # ABSTRACT: Contact for .US Registrations
 
 has 'nexus_purpose' => (
@@ -59,7 +59,6 @@ sub construct_from_response {
         nexus_category => $response->{NexusCategory},
     );
 
-
     return $contact;
 }
 
@@ -83,7 +82,7 @@ WWW::LogicBoxes::Contact::US - Representation of Domain Contact for .us Domains
 
     my $customer = WWW::LogicBoxes::Customer->new( ... ); # Valid LogicBoxes Customer
 
-    my $contact = WWW::LogicBoxes::Contact->new(
+    my $contact = WWW::LogicBoxes::Contact::US->new(
         id           => 42,
         name         => 'Edsger Dijkstra',
         company      => 'University of Texas at Austin',
