@@ -13,16 +13,11 @@ use Exporter 'import';
 our @EXPORT_OK = qw( create_api );
 
 sub create_api {
-    my (%args) = validated_hash(
-        \@_,
-        response_type => { isa => 'Str', default => 'xml' },
-    );
-
     if(    ! defined $ENV{PERL_WWW_LOGICBOXES_USERNAME}
-        || ! defined $ENV{PERL_WWW_LOGICBOXES_PASSWORD} ) {
+        || ! defined $ENV{PERL_WWW_LOGICBOXES_API_KEY} ) {
 
         plan( skip_all => "PERL_WWW_LOGICBOXES_USERNAME and"
-            . " PERL_WWW_LOGICBOXES_PASSWORD must be defined in"
+            . " PERL_WWW_LOGICBOXES_API_KEY must be defined in"
             . " order to run integration tests.");
     }
 
@@ -30,8 +25,8 @@ sub create_api {
     lives_ok {
         $api = WWW::LogicBoxes->new({
             username      => $ENV{PERL_WWW_LOGICBOXES_USERNAME},
-            password      => $ENV{PERL_WWW_LOGICBOXES_PASSWORD},
-            response_type => $args{response_type},
+            api_key       => $ENV{PERL_WWW_LOGICBOXES_API_KEY},
+            response_type => 'json',
             sandbox       => 1, # Since this is in the test suite it's always dev
         });
     } "Lives through WWW::LogicBoxes object creation";
